@@ -4,7 +4,7 @@ use base qw/Mojolicious::Plugin/;
 use Carp qw/croak/;
 use strict; 
 
-our $VERSION='0.2';
+our $VERSION='0.3';
 
 __PACKAGE__->attr(providers=>sub {
     return {
@@ -98,7 +98,7 @@ Mojolicious::Plugin::OAuth2 - Auth against OAUth2 APIs
 
 =head1 SYNOPSIS 
 
-   plugin 'o_auth2',
+   plugin 'OAuth2',
        facebook => {
           key => 'foo',
           secret => 'bar' 
